#!/usr/bin/env python
##########################################################################
# Copyright 2014 Elboulangero
#
# This file is part of Radio Tray
#
# Radio Tray is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 1 of the License, or
# (at your option) any later version.
#
# Radio Tray is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Radio Tray.  If not, see <http://www.gnu.org/licenses/>.
#
##########################################################################

from Plugin import Plugin

import gi
gi.require_version('Keybinder', '3.0')

from gi.repository import GLib
from gi.repository import Keybinder

class XMediaKeysPlugin(Plugin):

    def __init__(self):
        super(XMediaKeysPlugin, self).__init__()

    def initialize(self, name, eventManagerWrapper, eventSubscriber, provider, cfgProvider, mediator, tooltip):
        
        self.name = name
        self.eventManagerWrapper = eventManagerWrapper
        self.eventSubscriber = eventSubscriber
        self.provider = provider
        self.cfgProvider = cfgProvider
        self.mediator = mediator
        self.tooltip = tooltip

    def keybinder_init(self, data):
        self.log.debug("Keybinder init")
        Keybinder.init()
        Keybinder.bind("XF86AudioPlay", self.handle_play, None)
        Keybinder.bind("XF86AudioPause", self.handle_pause, None)
        Keybinder.bind("XF86AudioStop", self.handle_stop, None)
        Keybinder.bind("XF86AudioNext", self.handle_next, None)
        Keybinder.bind("XF86AudioPrev", self.handle_prev, None)

    def activate(self):
        GLib.idle_add(self.keybinder_init, None)

    def handle_play(self, keystr, data):
        self.log.debug("XMediaKeys: play")
        if not self.mediator.isPlaying():
            self.mediator.playLast()

    def handle_pause(self, keystr, data):
        self.log.debug("XMediaKeys: pause")
        if self.mediator.isPlaying():
            self.mediator.stop()
        else:
            self.mediator.playLast()

    def handle_stop(self, keystr, data):
        self.log.debug("XMediaKeys: stop")
        self.mediator.stop()

    def handle_next(self, keystr, data):
        self.log.debug("XMediaKeys: next")
        self.mediator.next()

    def handle_prev(self, keystr, data):
        self.log.debug("XMediaKeys: prev")
        self.mediator.previous()
